@@ -17,7 +17,7 @@ import { ListModel } from '@jupyterlab/extensionmanager';
 import { IChatService } from './Services/IChatService';
 import { IConfig } from './Config/ConfigService';
 import { ServiceManager } from '@jupyterlab/services';
-import { StateDBCachingService, STATE_DB_KEYS } from './utils/stateDBCaching';
+import { StateDBCachingService, STATE_DB_KEYS } from './utils/backendCaching';
 import { MentionContext } from './Chat/ChatContextMenu/ChatContextLoaders';
 import { DiffNavigationWidget } from './Components/DiffNavigationWidget';
 import { v4 as uuidv4 } from 'uuid';
@@ -889,13 +889,14 @@ export const AppStateService = {
   saveInsertedSnippets: async (): Promise<void> => {
     try {
       const currentState = AppStateService.getState();
+      const insertedSnippets = currentState.insertedSnippets || [];
       await StateDBCachingService.setObjectValue(
         STATE_DB_KEYS.INSERTED_SNIPPETS,
-        currentState.insertedSnippets
+        insertedSnippets
       );
       console.log(
         '[AppStateService] Saved',
-        currentState.insertedSnippets.length,
+        insertedSnippets.length,
         'inserted snippets to StateDB'
       );
     } catch (error) {
@@ -911,8 +912,9 @@ export const AppStateService = {
    */
   addInsertedSnippet: async (snippetId: string): Promise<void> => {
     const currentState = AppStateService.getState();
-    if (!currentState.insertedSnippets.includes(snippetId)) {
-      const newInsertedSnippets = [...currentState.insertedSnippets, snippetId];
+    const insertedSnippets = currentState.insertedSnippets || [];
+    if (!insertedSnippets.includes(snippetId)) {
+      const newInsertedSnippets = [...insertedSnippets, snippetId];
       AppStateService.setState({
         insertedSnippets: newInsertedSnippets
       });
@@ -941,7 +943,8 @@ export const AppStateService = {
    */
   removeInsertedSnippet: async (snippetId: string): Promise<void> => {
     const currentState = AppStateService.getState();
-    const newInsertedSnippets = currentState.insertedSnippets.filter(
+    const insertedSnippets = currentState.insertedSnippets || [];
+    const newInsertedSnippets = insertedSnippets.filter(
       id => id !== snippetId
     );
 
@@ -972,17 +975,27 @@ export const AppStateService = {
    */
   getInsertedSnippets: (): ISnippet[] => {
     const currentState = AppStateService.getState();
+    const insertedSnippets = currentState.insertedSnippets || [];
     return currentState.snippets.filter(snippet =>
-      currentState.insertedSnippets.includes(snippet.id)
+      insertedSnippets.includes(snippet.id)
     );
   },
 
+  /**
+   * Get the array of inserted snippet IDs safely (never null/undefined)
+   */
+  getInsertedSnippetIds: (): string[] => {
+    const currentState = AppStateService.getState();
+    return currentState.insertedSnippets || [];
+  },
+
   /**
    * Check if a snippet is currently inserted
    */
   isSnippetInserted: (snippetId: string): boolean => {
     const currentState = AppStateService.getState();
-    return currentState.insertedSnippets.includes(snippetId);
+    const insertedSnippets = currentState.insertedSnippets || [];
+    return insertedSnippets.includes(snippetId);
   },
 
   /**
