@@ -629,9 +629,23 @@ export class ChatInputManager {
 
       // Only show error if we're not cancelled
       if (this.chatService.getRequestStatus() !== ChatRequestStatus.CANCELLED) {
-        this.messageComponent.addErrorMessage(
-          `❌ ${error instanceof Error ? error.message : 'An error occurred while communicating with the AI service.'}`
-        );
+        // Check if this is a subscription/authentication error
+        const errorMessage = error instanceof Error ? error.message : String(error);
+        
+        // Check for authentication errors in the error message
+        const isAuthError = errorMessage.includes('authentication_error') || 
+                           errorMessage.includes('Invalid API key') ||
+                           (errorMessage.includes('401') && errorMessage.includes('error'));
+        
+        if (isAuthError) {
+          // Display subscription card instead of error message
+          this.messageComponent.displaySubscriptionCard();
+        } else {
+          // Display regular error message
+          this.messageComponent.addErrorMessage(
+            `❌ ${errorMessage}`
+          );
+        }
       }
     } finally {
       // Reset state
