@@ -24,7 +24,7 @@ import {
   StreamingState
 } from './ConversationServiceUtils';
 import { DiffStateService } from '../Services/DiffStateService';
-import { STATE_DB_KEYS, StateDBCachingService } from '../utils/stateDBCaching';
+import { STATE_DB_KEYS, StateDBCachingService } from '../utils/backendCaching';
 import { NotebookCellStateService } from '../Services/NotebookCellStateService';
 import { CheckpointManager } from '../Services/CheckpointManager';
 
