@@ -7,6 +7,7 @@ import { AnthropicStreamHandler } from './AnthropicStreamHandler';
 import { AnthropicMessageCreator } from './AnthropicMessageCreator';
 import { ServiceUtils } from './ServiceUtils';
 import { AppStateService } from '../AppState';
+import { JupyterAuthService } from './JupyterAuthService';
 
 type Headers = Record<string, string>;
 
@@ -14,7 +15,6 @@ type Headers = Record<string, string>;
  * Service for handling Anthropic API interactions
  */
 export class AnthropicService implements IChatService {
-  private client: Anthropic | null = null;
   private modelName: string = 'claude-3-7-sonnet-20250219';
   private modelUrl: string = 'https://api.anthropic.com/v1/messages';
   private requestStatus: ChatRequestStatus = ChatRequestStatus.IDLE;
@@ -28,21 +28,16 @@ export class AnthropicService implements IChatService {
   private toolBlacklist: string[] = [];
 
   /**
-   * Initialize the Anthropic client
-   * @param apiKey API key for authentication (optional - will use config if not provided)
+   * Initialize the Anthropic service (loads configuration)
+   * @param apiKey API key for authentication (optional - kept for interface compatibility)
    * @returns boolean indicating if initialization was successful
    */
   async initialize(apiKey?: string): Promise<boolean> {
     try {
-      // If already initialized, no-op
-      if (this.client) {
-        return true;
-      }
-      // Always try to get settings from AppState first to ensure we have the latest settings
+      // Always refresh configuration to ensure we have the latest settings
       try {
         const config = await ConfigService.getConfig();
-        console.log('Initializing Anthropic client with config:', config);
-        apiKey = config.claude.api_key;
+        console.log('Initializing Anthropic service with config:', config);
         this.systemPrompt = config.claude.system_prompt;
         this.systemPromptAskMode = config.claude_ask_mode.system_prompt;
         this.systemPromptFastMode = config.fast_mode.system_prompt;
@@ -53,22 +48,34 @@ export class AnthropicService implements IChatService {
         console.log('AppState not available, falling back to config');
       }
 
+      return true;
+    } catch (error) {
+      console.error('Failed to initialize Anthropic service:', error);
+      return false;
+    }
+  }
+
+  /**
+   * Get a fresh Anthropic client with the current API key from settings
+   * @returns Anthropic client instance or null if API key is not available
+   */
+  private async getClient(): Promise<Anthropic | null> {
+    try {
+      const config = await ConfigService.getConfig();
+      const apiKey = config.claude.api_key;
+
       if (!apiKey || apiKey.trim() === '') {
-        this.client = null;
-        return false;
+        return null;
       }
 
-      this.client = new Anthropic({
+      return new Anthropic({
         apiKey,
         baseURL: this.modelUrl,
         dangerouslyAllowBrowser: true
       });
-
-      return true;
     } catch (error) {
-      console.error('Failed to initialize Anthropic client:', error);
-      this.client = null;
-      return false;
+      console.error('Failed to get API key from config:', error);
+      return null;
     }
   }
 
@@ -111,11 +118,13 @@ export class AnthropicService implements IChatService {
   }
 
   /**
-   * Check if the Anthropic client is initialized
-   * @returns boolean indicating if the client is initialized
+   * Check if the Anthropic service can create a client (has valid API key)
+   * @returns boolean indicating if the service can function
    */
   isInitialized(): boolean {
-    return this.client !== null;
+    // Since we get the client dynamically, we consider it initialized
+    // if we can potentially get a configuration (the initialize method succeeded)
+    return true;
   }
 
   /**
@@ -186,6 +195,17 @@ export class AnthropicService implements IChatService {
     errorLogger?: (message: any) => Promise<void>,
     forceRetry: boolean = false
   ): Promise<any> {
+    // Check JWT token authentication before sending message
+    const jwtToken = await JupyterAuthService.getJwtToken();
+    if (!jwtToken) {
+      // Display authentication card in chatbox instead of sending message
+      const chatContainer = AppStateService.getState().chatContainer;
+      if (chatContainer?.chatWidget?.messageComponent) {
+        chatContainer.chatWidget.messageComponent.displayAuthenticationCard();
+      }
+      return { cancelled: true, reason: 'Authentication required' };
+    }
+
     await this.validateClientInitialized(errorLogger);
     this.initializeRequest();
 
@@ -261,9 +281,20 @@ export class AnthropicService implements IChatService {
     onRetry?: (error: Error, attemptNumber: number) => Promise<void>,
     feature?: 'cmd-k' | 'chat'
   ): Promise<string | CancelledRequest> {
-    if (!this.client) {
+    // Check JWT token authentication before sending ephemeral message
+    const jwtToken = await JupyterAuthService.getJwtToken();
+    if (!jwtToken) {
+      // For ephemeral messages (like cmd-k), we don't display auth card, just return early
+      return {
+        cancelled: true,
+        reason: 'Authentication required'
+      } as CancelledRequest;
+    }
+
+    const client = await this.getClient();
+    if (!client) {
       throw new Error(
-        'Anthropic client not initialized. Please set API key first.'
+        'Anthropic client not available. Please check your API key configuration.'
       );
     }
 
@@ -272,6 +303,7 @@ export class AnthropicService implements IChatService {
 
     try {
       return await this.executeEphemeralRequest(
+        client,
         message,
         systemPrompt,
         modelName,
@@ -297,6 +329,7 @@ export class AnthropicService implements IChatService {
    * Execute the core ephemeral request without retry logic
    */
   private async executeEphemeralRequest(
+    client: Anthropic,
     message: string,
     systemPrompt: string,
     modelName: string,
@@ -314,12 +347,12 @@ export class AnthropicService implements IChatService {
       };
     }
 
-    const maxTokens = options?.maxTokens ?? 48;
+    const maxTokens = options?.maxTokens ?? 4096;
     const temperature = options?.temperature ?? 0;
 
     if (onTextChunk) {
       // Use streaming for real-time updates
-      const stream = await this.client!.messages.stream(
+      const stream = await client.messages.stream(
         {
           model: modelName,
           max_tokens: maxTokens,
@@ -355,7 +388,7 @@ export class AnthropicService implements IChatService {
       return completeResponse;
     } else {
       // Use non-streaming for simple responses
-      const response = await this.client!.messages.create(
+      const response = await client.messages.create(
         {
           model: modelName,
           max_tokens: maxTokens,
@@ -421,8 +454,17 @@ export class AnthropicService implements IChatService {
         // Wait before retry
         await this.waitForRetry(retryDelays[attempt - 1]);
 
+        // Get a fresh client for retry
+        const retryClient = await this.getClient();
+        if (!retryClient) {
+          throw new Error(
+            'Anthropic client not available for retry. Please check your API key configuration.'
+          );
+        }
+
         // Retry the request
         return await this.executeEphemeralRequest(
+          retryClient,
           message,
           systemPrompt,
           modelName,
@@ -455,16 +497,17 @@ export class AnthropicService implements IChatService {
   }
 
   /**
-   * Validates that the client is initialized
+   * Validates that the client can be created with current API key
    */
   private async validateClientInitialized(
     errorLogger?: (message: any) => Promise<void>
-  ): Promise<void> {
-    if (!this.client) {
+  ): Promise<Anthropic> {
+    const client = await this.getClient();
+    if (!client) {
       const errMsg = {
-        message: 'Anthropic client not initialized. Please set API key first.',
+        message:
+          'Anthropic client not available. Please check your API key configuration.',
         variables: {
-          client: this.client,
           modelName: this.modelName,
           modelUrl: this.modelUrl,
           requestStatus: this.requestStatus
@@ -473,6 +516,7 @@ export class AnthropicService implements IChatService {
       errorLogger && (await errorLogger(JSON.stringify(errMsg)));
       throw new Error(errMsg.message);
     }
+    return client;
   }
 
   /**
@@ -566,9 +610,11 @@ export class AnthropicService implements IChatService {
     customHeaders: Headers = {}
   ): Promise<any> {
     try {
+      const client = await this.validateClientInitialized(errorLogger);
+
       return await AnthropicMessageCreator.createMessageStream(
         {
-          client: this.client!,
+          client: client,
           modelName: this.modelName,
           systemPrompt: this.systemPrompt,
           systemPromptAskMode: this.systemPromptAskMode,
@@ -693,6 +739,7 @@ export class AnthropicService implements IChatService {
     forceRetry: boolean,
     errorLogger?: (message: any) => Promise<void>
   ): Promise<boolean> {
+    // Skip retry for 400 Bad Request errors
     if (
       error.name === 'BadRequestError' &&
       error.status === 400 &&
@@ -705,6 +752,45 @@ export class AnthropicService implements IChatService {
       });
       return true;
     }
+
+    // Skip retry for 401 authentication errors (subscription required)
+    if (error.status === 401) {
+      this.requestStatus = ChatRequestStatus.ERROR;
+      await errorLogger?.({
+        message: 'Authentication error (401) - not retrying',
+        error: error instanceof Error ? error.message : error
+      });
+
+      // Display subscription card immediately
+      const chatContainer = AppStateService.getState().chatContainer;
+      if (chatContainer?.chatWidget?.messageComponent) {
+        chatContainer.chatWidget.messageComponent.displaySubscriptionCard();
+      }
+
+      return true;
+    }
+
+    // Also check for authentication_error in the message content
+    const errorMessage = error instanceof Error ? error.message : String(error);
+    if (
+      errorMessage.includes('authentication_error') ||
+      errorMessage.includes('Invalid API key')
+    ) {
+      this.requestStatus = ChatRequestStatus.ERROR;
+      await errorLogger?.({
+        message: 'Authentication error detected - not retrying',
+        error: errorMessage
+      });
+
+      // Display subscription card immediately
+      const chatContainer = AppStateService.getState().chatContainer;
+      if (chatContainer?.chatWidget?.messageComponent) {
+        chatContainer.chatWidget.messageComponent.displaySubscriptionCard();
+      }
+
+      return true;
+    }
+
     return false;
   }
 
@@ -883,6 +969,8 @@ export class AnthropicService implements IChatService {
       'X-Sage-Client-Lab-Version'?: string;
       'X-Sage-Session-Id'?: string;
       'X-Sage-Thread-Id'?: string;
+      Origin?: string;
+      Referer?: string;
     } = {};
 
     if (mode) {
@@ -893,6 +981,10 @@ export class AnthropicService implements IChatService {
       headers['X-Sage-Feature'] = feature;
     }
 
+    // Add CORS headers to match working web app requests
+    headers['Origin'] = 'https://app.signalpilot.ai';
+    headers['Referer'] = 'https://app.signalpilot.ai/';
+
     // Always get notebook ID from AppState
     const notebookId = AppStateService.getCurrentNotebookId();
     if (notebookId) {
