@@ -10,7 +10,7 @@ import { IStateDB } from '@jupyterlab/statedb';
 import { IDocumentManager } from '@jupyterlab/docmanager';
 import { ISettingRegistry } from '@jupyterlab/settingregistry';
 import { CachingService, SETTING_KEYS } from './utils/caching';
-import { StateDBCachingService } from './utils/stateDBCaching';
+import { StateDBCachingService } from './utils/backendCaching';
 import { AppStateService } from './AppState';
 import { ListModel } from '@jupyterlab/extensionmanager';
 import { ConfigService } from './Config/ConfigService';
@@ -36,6 +36,7 @@ import { Widget } from '@lumino/widgets';
 import { NotebookSettingsContainer } from './NotebookSettingsContainer';
 import { SnippetCreationWidget } from './Components/SnippetCreationWidget';
 import { DiffNavigationWidget } from './Components/DiffNavigationWidget';
+import { FileExplorerWidget } from './Components/FileExplorerWidget';
 import { NotebookChatContainer } from './Notebook/NotebookChatContainer';
 import { KernelUtils } from './utils/kernelUtils';
 import { registerCommands } from './commands';
@@ -70,14 +71,16 @@ export async function activateSage(
   CachingService.initialize(settingRegistry);
 
   // Initialize the state database caching service for chat histories
-  StateDBCachingService.initialize(db);
+  StateDBCachingService.initialize();
 
   // Initialize JWT authentication immediately on startup (CRITICAL: Do this early!)
   console.log('[Plugin] Initializing JWT authentication on startup...');
   try {
     const jwtInitialized = await JWTAuthModalService.initializeJWTOnStartup();
     if (jwtInitialized) {
-      console.log('[Plugin] JWT authentication initialized successfully on startup');
+      console.log(
+        '[Plugin] JWT authentication initialized successfully on startup'
+      );
     } else {
       console.log('[Plugin] No JWT token found during startup initialization');
     }
@@ -447,6 +450,7 @@ export async function activateSage(
   let settingsContainer: NotebookSettingsContainer | undefined;
   let snippetCreationWidget: SnippetCreationWidget | undefined;
   let diffNavigationWidget: DiffNavigationWidget | undefined;
+  let fileExplorerWidget: FileExplorerWidget | undefined;
 
   const initializeChatContainer = async () => {
     // Get existing chat container from AppState
@@ -566,6 +570,29 @@ export async function activateSage(
     return snippetCreationWidget;
   };
 
+  const initializeFileExplorerWidget = () => {
+    // Create a new file explorer widget
+    const createWidget = () => {
+      const newWidget = new FileExplorerWidget();
+
+      // Set the app instance for file browser operations
+      newWidget.setApp(app);
+
+      tracker.add(newWidget);
+
+      // Add the widget to the left side panel with a different rank
+      app.shell.add(newWidget, 'left', { rank: 1001 });
+
+      return newWidget;
+    };
+
+    if (!fileExplorerWidget || fileExplorerWidget.isDisposed) {
+      fileExplorerWidget = createWidget();
+    }
+
+    return fileExplorerWidget;
+  };
+
   const initializeDiffNavigationWidget = () => {
     // Create a new diff navigation widget
     const createWidget = () => {
@@ -609,6 +636,7 @@ export async function activateSage(
   void initializeChatContainer();
   settingsContainer = initializeSettingsContainer();
   snippetCreationWidget = initializeSnippetCreationWidget();
+  fileExplorerWidget = initializeFileExplorerWidget();
   diffNavigationWidget = initializeDiffNavigationWidget();
 
   // Store widget references globally for cleanup
@@ -617,7 +645,7 @@ export async function activateSage(
 
   // Initialize JWT authentication check - show modal if user is not authenticated
   const jwtModalService = JWTAuthModalService.getInstance();
-  
+
   // Listen for settings widget state changes to detect authentication
   if (settingsContainer) {
     const settingsWidget = settingsContainer.getSettingsWidget();
@@ -629,7 +657,7 @@ export async function activateSage(
       }
     });
   }
-  
+
   // Check authentication status after initialization
   void app.restored.then(async () => {
     // Wait a bit for everything to settle, then check authentication
@@ -865,7 +893,9 @@ export async function activateSage(
       (window as any).debugLoginSuccess = {
         show: async () => {
           try {
-            const { LoginSuccessModalService } = await import('./Services/LoginSuccessModalService');
+            const { LoginSuccessModalService } = await import(
+              './Services/LoginSuccessModalService'
+            );
             LoginSuccessModalService.debugShow();
             console.log('✅ Login success modal triggered from debug');
           } catch (error) {
@@ -874,7 +904,9 @@ export async function activateSage(
         },
         getDebugInfo: async () => {
           try {
-            const { LoginSuccessModalService } = await import('./Services/LoginSuccessModalService');
+            const { LoginSuccessModalService } = await import(
+              './Services/LoginSuccessModalService'
+            );
             const instance = LoginSuccessModalService.getInstance();
             return instance.getDebugInfo();
           } catch (error) {
