@@ -1,8 +1,8 @@
 import { JupyterFrontEnd } from '@jupyterlab/application';
 import { ICommandPalette } from '@jupyterlab/apputils';
 import { AppStateService } from './AppState';
-import { StateDBCachingService, STATE_DB_KEYS } from './utils/stateDBCaching';
-import { inlineDiffService } from './Notebook/InlineDiffService';
+import { StateDBCachingService, STATE_DB_KEYS } from './utils/backendCaching';
+import { requestAPI } from './handler';
 
 /**
  * Register all commands for the sage-ai extension
@@ -37,6 +37,8 @@ export function registerCommands(
 
   // Register clear error logs command
   registerClearErrorLogsCommand(app, palette);
+
+  registerHelloWorldCommand(app, palette);
 }
 
 /**
@@ -621,3 +623,38 @@ function registerClearErrorLogsCommand(
   // Add this command to the command palette
   palette.addItem({ command: clearErrorLogsCommand, category: 'AI Tools' });
 }
+
+function registerHelloWorldCommand(
+  app: JupyterFrontEnd,
+  palette: ICommandPalette
+): void {
+  const helloWorldCommand: string = 'sage-ai:hello-world';
+
+  app.commands.addCommand(helloWorldCommand, {
+    label: 'Test Backend Hello World',
+    execute: async () => {
+      try {
+        // Call the hello world endpoint
+        const data = await requestAPI<any>('hello-world');
+        console.log('Backend response:', data);
+
+        // Show a notification or log the response
+        if (data && data.data) {
+          console.log('✅ Backend connection successful!');
+          console.log('📩 Message:', data.data);
+          if (data.message) {
+            console.log('📝 Details:', data.message);
+          }
+        }
+      } catch (error) {
+        console.error('❌ Failed to connect to backend:', error);
+        console.error(
+          'The signalpilot-ai-internal server extension appears to be missing or not running.'
+        );
+      }
+    }
+  });
+
+  // Add the hello world command to the command palette
+  palette.addItem({ command: helloWorldCommand, category: 'AI Tools' });
+}
