@@ -24,7 +24,8 @@ import {
 import posthog from 'posthog-js';
 
 const POSTHOG_PROJECT_API_KEY =
-  'phc_QlxCEiEs9dDEMKmqgtt7LwwFGYfuh6ABbbOC3Qqyq17';
+  'phc_E3oZ3UN1nOoWsMMKtPBAGKSqQCtuKutiwmfUZAu3ybr';
+
 /**
  * Initialization data for the sage-ai extension
  */
@@ -72,14 +73,14 @@ export const plugin: JupyterFrontEndPlugin<void> = {
       try {
         // Import StateDBCachingService and JupyterAuthService dynamically to avoid circular dependencies
         const { StateDBCachingService } = await import(
-          './utils/stateDBCaching'
+          './utils/backendCaching'
         );
         const { JupyterAuthService } = await import(
           './Services/JupyterAuthService'
         );
 
         // Initialize StateDB caching service early so authentication can use it
-        StateDBCachingService.initialize(db);
+        StateDBCachingService.initialize();
 
         // Check for temp_token in URL and handle authentication callback
         const urlParams = new URLSearchParams(window.location.search);
